@@ -7,7 +7,7 @@
 #include <ngxe_xs.h>
 #include <ngxe_connection.h>
 
-int ngxe_initialized;
+#define NGXE_START  0x01
 
 #endif /* _NGXE_H_INCLUDED_ */
 
